@@ -10,10 +10,15 @@ const (
 	modeUnique    = "unique"
 	modeSharedOps = "shared_ops"
 
-	defaultMode          = modeSharedOps
-	defaultCPURequest    = "100m"
-	defaultMemoryLimit   = "4Gi"
-	defaultMemoryRequest = "1Gi"
+	defaultMode = modeSharedOps
+	// ES
+	defaultESCpuRequest    = "100m"
+	defaultESMemoryLimit   = "4Gi"
+	defaultESMemoryRequest = "1Gi"
+	// ESProxy
+	defaultESProxyCpuRequest    = "100m"
+	defaultESProxyMemoryLimit   = "256Mi"
+	defaultESProxyMemoryRequest = "256Mi"
 
 	maxMasterCount = 3
 
